@@ -9,7 +9,6 @@
 #include "settings.h"
 #include "kcoreaddons_version.h"
 
-#include <KPluginLoader>
 #include <KSharedConfig>
 
 #include <QFileInfo>
@@ -123,8 +122,9 @@ QStringList PluginManager::supportedMimeTypes(MimeSortingMode mode) const
         supported.remove(QStringLiteral("application/x-lz4-compressed-tar"));
     }
 
+    static bool s_libarchiveHasLzo = libarchiveHasLzo();
     // Remove entry for lzo-compressed tar if libarchive not linked against lzo and lzop executable not found in path.
-    if (!libarchiveHasLzo() && QStandardPaths::findExecutable(QStringLiteral("lzop")).isEmpty()) {
+    if (!s_libarchiveHasLzo && QStandardPaths::findExecutable(QStringLiteral("lzop")).isEmpty()) {
         supported.remove(QStringLiteral("application/x-tzo"));
     }
 
@@ -194,11 +194,7 @@ QVector<Plugin*> PluginManager::filterBy(const QVector<Plugin*> &plugins, const
 
 void PluginManager::loadPlugins()
 {
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 86, 0)
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"));
-#else
     const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kerfuffle"));
-#endif
     QSet<QString> addedPlugins;
     for (const KPluginMetaData &metaData : plugins) {
         const auto pluginId = metaData.pluginId();
